@@ -41,6 +41,15 @@ class Workspace(Addressable):
             except:
                 logger.debug("could not locate nameserver")
 
+    def unregister_agents(self):
+        for agent in self.__agents.values():
+            try:
+                ns = locateNS(self.ns_hostname)
+                ns.remove(prefix=AGENT)
+                logger.debug(ns.list())
+            except:
+                logger.debug("could not locate nameserver")
+
     def get_agent(self, address):
         return self.__agents[address]
 
@@ -58,3 +67,11 @@ class Workspace(Addressable):
             logger.debug(ns.list())
         except:
             logger.debug("could not locate nameserver")
+
+    def unregister(self):
+        try:
+            ns = locateNS(self.ns_hostname)
+            ns.remove(WORKSPACE + '.' + self.address)
+            logger.debug(ns.list())
+        except:
+            logger.debug("could not locate nameserver")
